Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(715)

Unified Diff: media/base/filter_host_impl.h

Issue 155338: Implemented injected message loops for PipelineImpl. (Closed)
Patch Set: Merged with git-svn Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/base/filter_host_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/filter_host_impl.h
diff --git a/media/base/filter_host_impl.h b/media/base/filter_host_impl.h
index 1fcb0c4f50d34a400f5d8fb65ebc93b66f2690c6..71e2417691d1a912bd8e9379af953183d5302055 100644
--- a/media/base/filter_host_impl.h
+++ b/media/base/filter_host_impl.h
@@ -27,15 +27,15 @@ class FilterHostImpl : public FilterHost {
virtual void SetVideoSize(size_t width, size_t height);
// These methods are public, but are intended for use by the
// PipelineThread class only.
// Creates a FilterHostImpl object and populates the |filter_type_| member
// by calling the Filter class's static filter_type() method. This ensures
// that the GetFilter method can safely cast the filter interface from the
// MediaFilter base class interface to the specific Filter interface.
template <class Filter>
- FilterHostImpl(PipelineThread* pipeline_thread, Filter* filter)
- : pipeline_thread_(pipeline_thread),
+ FilterHostImpl(PipelineInternal* pipeline_internal, Filter* filter)
+ : pipeline_internal_(pipeline_internal),
filter_type_(Filter::filter_type()),
filter_(filter),
stopped_(false) {
@@ -54,15 +54,16 @@ class FilterHostImpl : public FilterHost {
// Stops the filter.
void Stop();
// Used by the PipelineThread to call Seek and SetRate methods on filters.
MediaFilter* media_filter() const { return filter_; }
private:
// Useful method for getting the pipeline.
- PipelineImpl* pipeline() const { return pipeline_thread_->pipeline(); }
+ PipelineImpl* pipeline() const { return pipeline_internal_->pipeline(); }
- // PipelineThread that owns this FilterHostImpl.
- PipelineThread* const pipeline_thread_;
+ // PipelineInternal that owns this FilterHostImpl.
+ PipelineInternal* const pipeline_internal_;
// The FilterType of the filter this host contains.
FilterType const filter_type_;
« no previous file with comments | « no previous file | media/base/filter_host_impl.cc » ('j') | no next file with comments »
@@ -27,15 +27,15 @@ class FilterHostImpl : public FilterHost {
virtual void SetVideoSize(size_t width, size_t height);
// These methods are public, but are intended for use by the
- // PipelineThread class only.
+ // PipelineInternal class only.
// Creates a FilterHostImpl object and populates the |filter_type_| member
// by calling the Filter class's static filter_type() method. This ensures
@@ -54,15 +54,16 @@ class FilterHostImpl : public FilterHost {
// Stops the filter.
void Stop();
- // Used by the PipelineThread to call Seek and SetRate methods on filters.
+ // Used by the PipelineInternal to call Seek() and SetRate() methods on
+ // filters.
MediaFilter* media_filter() const { return filter_; }
private:

Powered by Google App Engine
This is Rietveld 408576698